@@ -1,17 +1,21 @@
 
 .source_list <- function(tax, ...) {
-    if (! exists("source_id_map", tax)) {
-        ## it should only be missing with tol_about when using
-        ## include_source_list=FALSE
-        stop("Make sure that your object has been created using ",
-             sQuote("tol_about(include_source_list = TRUE)"))
-    }
-    tt <- lapply(tax[["source_id_map"]], function(x) {
-        c(x[["study_id"]], x[["tree_id"]], x[["git_sha"]])
-    })
-    tt <- do.call("rbind", tt)
-    setNames(as.data.frame(tt, stringsAsFactors=FALSE),
-             c("study_id", "tree_id", "git_sha"))
+  if (!exists("source_id_map", tax)) {
+    ## it should only be missing with tol_about when using
+    ## include_source_list=FALSE
+    stop(
+      "Make sure that your object has been created using ",
+      sQuote("tol_about(include_source_list = TRUE)")
+    )
+  }
+  tt <- lapply(tax[["source_id_map"]], function(x) {
+    c(x[["study_id"]], x[["tree_id"]], x[["git_sha"]])
+  })
+  tt <- do.call("rbind", tt)
+  setNames(
+    as.data.frame(tt, stringsAsFactors = FALSE),
+    c("study_id", "tree_id", "git_sha")
+  )
 }
 
 ##' Basic information about the Open Tree of Life (the synthetic tree)
@@ -54,7 +58,7 @@
 ##'         \itemize{
 ##'             \item {node_id} {String. The canonical identifier of the node.}
 ##'
-##'             \item {num_tips} {Numeric. The number of descendent tips.}
+##'             \item {num_tips} {Numeric. The number of descendant tips.}
 ##'
 ##'             \item {taxon} {A list of taxonomic properties:}
 ##'             \itemize{
@@ -108,35 +112,35 @@
 ##' studies <- source_list(tol_about(include_source_list=TRUE))}
 ##' @rdname tol_about
 ##' @export
-tol_about <- function(include_source_list=FALSE, ...) {
-    res <- .tol_about(include_source_list=include_source_list, ...)
-    class(res) <- c("tol_summary", class(res))
-    res
+tol_about <- function(include_source_list = FALSE, ...) {
+  res <- .tol_about(include_source_list = include_source_list, ...)
+  class(res) <- c("tol_summary", class(res))
+  res
 }
 
 
 ##' @export
 print.tol_summary <- function(x, ...) {
-    cat("\nOpenTree Synthetic Tree of Life.\n\n")
-    cat("Tree version: ", x$synth_id, "\n", sep="")
-    cat("Taxonomy version: ", x$taxonomy, "\n", sep="")
-    cat("Constructed on: ", x$date_created, "\n", sep="")
-    cat("Number of terminal taxa: ", x$root$num_tips, "\n", sep="")
-    cat("Number of source trees: ", x$num_source_trees, "\n", sep="")
-    cat("Number of source studies: ", x$num_source_studies, "\n", sep = "")
-    cat("Source list present: ", ifelse(exists("source_list", x), "true", "false"), "\n", sep="")
-    cat("Root taxon: ", x$root$taxon$name, "\n", sep="")
-    cat("Root ott_id: ", x$root$taxon$ott_id, "\n", sep="")
-    cat("Root node_id: ", x$root$node_id, "\n", sep="")
+  cat("\nOpenTree Synthetic Tree of Life.\n\n")
+  cat("Tree version: ", x$synth_id, "\n", sep = "")
+  cat("Taxonomy version: ", x$taxonomy, "\n", sep = "")
+  cat("Constructed on: ", x$date_created, "\n", sep = "")
+  cat("Number of terminal taxa: ", x$root$num_tips, "\n", sep = "")
+  cat("Number of source trees: ", x$num_source_trees, "\n", sep = "")
+  cat("Number of source studies: ", x$num_source_studies, "\n", sep = "")
+  cat("Source list present: ", ifelse(exists("source_list", x), "true", "false"), "\n", sep = "")
+  cat("Root taxon: ", x$root$taxon$name, "\n", sep = "")
+  cat("Root ott_id: ", x$root$taxon$ott_id, "\n", sep = "")
+  cat("Root node_id: ", x$root$node_id, "\n", sep = "")
 }
 
 tol_about_method_factory <- function(.f) {
-    function(tax, ...) {
-        res <- list(.f(tax[["root"]][["taxon"]]))
-        names(res) <- .tax_unique_name(tax[["root"]][["taxon"]])
-        res <- add_otl_class(res, .f)
-        res
-    }
+  function(tax, ...) {
+    res <- list(.f(tax[["root"]][["taxon"]]))
+    names(res) <- .tax_unique_name(tax[["root"]][["taxon"]])
+    res <- add_otl_class(res, .f)
+    res
+  }
 }
 
 ##' @export
@@ -181,7 +185,7 @@ source_list.tol_summary <- .source_list
 ##'     nodes is not in the synthetic tree an error will be returned.
 ##'
 ##'     Taxonomic methods (\code{tax_sources()}, \code{ott_id()},
-##'     \code{unique_name()}, ...) are availble on the objects
+##'     \code{unique_name()}, ...) are available on the objects
 ##'     returned by \code{tol_mrca()}. If the MRCA node is MRTA, the
 ##'     name of the object returned by these methods will start with
 ##'     \sQuote{ott}, otherwise it will start with \sQuote{mrca}.
@@ -201,7 +205,7 @@ source_list.tol_summary <- .source_list
 ##'     \itemize{
 ##'         \item {node_id} {String. The canonical identifier of the node.}
 ##'
-##'         \item {num_tips} {Numeric. The number of descendent tips.}
+##'         \item {num_tips} {Numeric. The number of descendant tips.}
 ##'
 ##'         \item {taxon} {A list of taxonomic properties. Only returned if
 ##'         the queried node is a taxon. (If the node is not a taxon, a
@@ -286,48 +290,49 @@ source_list.tol_summary <- .source_list
 ##'
 ##' @examples
 ##' \dontrun{
-##' birds_mrca <- tol_mrca(ott_ids=c(412129, 536234))
+##' birds_mrca <- tol_mrca(ott_ids=c(412129, 119214))
 ##' ott_id(birds_mrca)
-##' tax_sources(birds_mrca)}
+##' tax_sources(birds_mrca)
+##' }
 ##' @rdname tol_mrca
 ##' @export
-tol_mrca <- function(ott_ids=NULL, node_ids=NULL, ...) {
-    res <- .tol_mrca(ott_ids=ott_ids, node_ids=node_ids, ...)
-    class(res) <- c("tol_mrca", class(res))
-    return(res)
+tol_mrca <- function(ott_ids = NULL, node_ids = NULL, ...) {
+  res <- .tol_mrca(ott_ids = ott_ids, node_ids = node_ids, ...)
+  class(res) <- c("tol_mrca", class(res))
+  return(res)
 }
 
 ##' @export
 print.tol_mrca <- function(x, ...) {
-    cat("\nOpenTree MRCA node.\n\n")
-    cat("Node id: ", x$mrca$node_id, "\n", sep="")
-    cat("Number of terminal descendants: ", x$mrca$num_tips, "\n", sep="")
-    if (is_taxon(x[["mrca"]][["taxon"]])) {
-        cat("Is taxon: TRUE\n")
-        cat("Name: ", x$mrca$taxon$name, "\n", sep="")
-        cat("ott id: ", x$mrca$taxon$ott_id, "\n", sep="")
-    } else {
-        cat("Is taxon: FALSE\n")
-        cat("Nearest taxon:\n")
-        cat("  Name: ", x$nearest_taxon$name, "\n", sep="")
-        cat("  ott id: ", x$nearest_taxon$ott_id, "\n", sep="")
-    }
+  cat("\nOpenTree MRCA node.\n\n")
+  cat("Node id: ", x$mrca$node_id, "\n", sep = "")
+  cat("Number of terminal descendants: ", x$mrca$num_tips, "\n", sep = "")
+  if (is_taxon(x[["mrca"]][["taxon"]])) {
+    cat("Is taxon: TRUE\n")
+    cat("Name: ", x$mrca$taxon$name, "\n", sep = "")
+    cat("ott id: ", x$mrca$taxon$ott_id, "\n", sep = "")
+  } else {
+    cat("Is taxon: FALSE\n")
+    cat("Nearest taxon:\n")
+    cat("  Name: ", x$nearest_taxon$name, "\n", sep = "")
+    cat("  ott id: ", x$nearest_taxon$ott_id, "\n", sep = "")
+  }
 }
 
 tol_mrca_method_factory <- function(.f) {
-    function(tax, ...) {
-        if (is_taxon(tax[["mrca"]][["taxon"]])) {
-            res <- list(.f(tax[["mrca"]][["taxon"]]))
-            names(res) <- .tax_unique_name(tax[["mrca"]][["taxon"]])
-            attr(res, "taxon_type") <- "mrca"
-        } else {
-            res <- list(.f(tax[["nearest_taxon"]]))
-            names(res) <- .tax_unique_name(tax[["nearest_taxon"]])
-            attr(res, "taxon_type") <- "nearest_taxon"
-        }
-        res <- add_otl_class(res, .f)
-        res
+  function(tax, ...) {
+    if (is_taxon(tax[["mrca"]][["taxon"]])) {
+      res <- list(.f(tax[["mrca"]][["taxon"]]))
+      names(res) <- .tax_unique_name(tax[["mrca"]][["taxon"]])
+      attr(res, "taxon_type") <- "mrca"
+    } else {
+      res <- list(.f(tax[["nearest_taxon"]]))
+      names(res) <- .tax_unique_name(tax[["nearest_taxon"]])
+      attr(res, "taxon_type") <- "nearest_taxon"
     }
+    res <- add_otl_class(res, .f)
+    res
+  }
 }
 
 ##' @export
@@ -378,7 +383,7 @@ source_list.tol_mrca <- .source_list
 ##'     \code{\link{rotl}} for more information).
 ##'
 ##' @return If no value is specified to the \code{file} argument
-##'     (default), a phyogenetic tree of class \code{phylo}.
+##'     (default), a phylogenetic tree of class \code{phylo}.
 ##'     Otherwise, the function returns invisibly a logical indicating
 ##'     whether the file was successfully created.
 ##'
@@ -386,19 +391,21 @@ source_list.tol_mrca <- .source_list
 ##' \dontrun{
 ##' res <- tol_subtree(ott_id=241841)}
 ##' @export
-tol_subtree <- function(ott_id=NULL, node_id=NULL, label_format=NULL,
+tol_subtree <- function(ott_id = NULL, node_id = NULL, label_format = NULL,
                         file, ...) {
-    res <- .tol_subtree(ott_id=ott_id, node_id=node_id,
-                        label_format=label_format, ...)
+  res <- .tol_subtree(
+    ott_id = ott_id, node_id = node_id,
+    label_format = label_format, ...
+  )
 
-    if (!missing(file)) {
-        unlink(file)
-        cat(res$newick, file=file)
-        return(invisible(file.exists(file)))
-    } else {
-        phy <- phylo_from_otl(res)
-        return(phy)
-    }
+  if (!missing(file)) {
+    unlink(file)
+    cat(res$newick, file = file)
+    return(invisible(file.exists(file)))
+  } else {
+    phy <- phylo_from_otl(res)
+    return(phy)
+  }
 }
 
 
@@ -411,43 +418,56 @@ tol_subtree <- function(ott_id=NULL, node_id=NULL, label_format=NULL,
 ##' synthetic tree. This tree is equivalent to the minimal subtree
 ##' induced on the draft tree by the set of identified nodes.
 ##'
-##' @param ott_ids Numeric vector. OTT ids indicating nodes to be used
-##'     as tips in the induced tree.
-##' @param node_ids Character vector. Node ids indicating nodes to be used
-##'     as tips in the induced tree.
+##' @param ott_ids Numeric vector. OTT ids indicating nodes to be used as tips
+##'     in the induced tree.
+##' @param node_ids Character vector. Node ids indicating nodes to be used as
+##'     tips in the induced tree.
 ##' @param label_format Character. Defines the label type; one of
-##'     \dQuote{\code{name}}, \dQuote{\code{id}}, or
-##'      \dQuote{\code{name_and_id}} (the default).
-##' @param file If specified, the function will write the subtree to a
-##'     file in newick format.
+##'     \dQuote{\code{name}}, \dQuote{\code{id}}, or \dQuote{\code{name_and_id}}
+##'     (the default).
+##' @param file If specified, the function will write the subtree to a file in
+##'     newick format.
 ##' @param ... additional arguments to customize the API call (see
 ##'     \code{\link{rotl}} for more information).
 ##'
 ##' @return If no value is specified to the \code{file} argument
-##'     (default), a phyogenetic tree of class \code{phylo}.
+##'     (default), a phylogenetic tree of class \code{phylo}.
 ##'
 ##'     Otherwise, the function returns invisibly a logical indicating
 ##'     whether the file was successfully created.
 ##'
+##'     Note that the tree returned when specifying a file name with the
+##'     \code{file} argument is the \dQuote{raw} Newick string returned by Open
+##'     Tree of Life. This string contains singleton nodes, and therefore will
+##'     be different from the tree returned as a \code{phylo} object which will
+##'     not contain these singleton nodes.
+##'
 ##' @examples
 ##' \dontrun{
-##' res <- tol_induced_subtree(ott_ids=c(292466, 267845, 666104, 316878, 102710))
-##' tree_file <- tempfile(fileext=".tre")
-##' tol_induced_subtree(ott_ids=c(292466, 267845, 666104, 316878, 102710),
-##'                     file=tree_file)}
+##' ## Result as a `phylo` object
+##' res <- tol_induced_subtree(ott_ids = c(292466, 267845, 316878, 102710))
+##'
+##' ## Raw Newick string from Open Tree of Life
+##' tree_file <- tempfile(fileext = ".tre")
+##' tol_induced_subtree(ott_ids = c(292466, 267845, 316878, 102710),
+##'                     file=tree_file)
+##'
+##' }
 ##' @export
-tol_induced_subtree <- function(ott_ids=NULL, node_ids=NULL, label_format=NULL,
+tol_induced_subtree <- function(ott_ids = NULL, node_ids = NULL, label_format = NULL,
                                 file, ...) {
-    res <- .tol_induced_subtree(ott_ids=ott_ids, node_ids=node_ids,
-                                label_format=label_format, ...)
-    if (!missing(file)) {
-        unlink(file)
-        cat(res$newick, file=file)
-        return(file.exists(file))
-    } else {
-        phy <- phylo_from_otl(res)
-        return(phy)
-    }
+  res <- .tol_induced_subtree(
+    ott_ids = ott_ids, node_ids = node_ids,
+    label_format = label_format, ...
+  )
+  if (!missing(file)) {
+    unlink(file)
+    cat(res$newick, file = file)
+    return(file.exists(file))
+  } else {
+    phy <- phylo_from_otl(res)
+    return(phy)
+  }
 }
 
 
@@ -462,18 +482,19 @@ tol_induced_subtree <- function(ott_ids=NULL, node_ids=NULL, label_format=NULL,
 ##'
 ##' @examples
 ##' \dontrun{
-##' genera <- c("Perdix", "Dendroica", "Cinclus", "Selasphorus", "Struthio")
-##' tr <- tol_induced_subtree(ott_ids=c(292466, 267845, 666104, 102710))
+##' genera <- c("Perdix", "Setophaga", "Cinclus", "Struthio")
+##' tr <- tol_induced_subtree(ott_ids=c(102710, 285198, 267845, 292466))
 ##' tr$tip.label %in% genera
 ##' tr$tip.label <- strip_ott_ids(tr$tip.label)
-##' tr$tip.label %in% genera}
-##'@export
-strip_ott_ids <- function(tip_labels, remove_underscores=FALSE){
-    stripped <- sub("_ott\\d+$", "", tip_labels)
-    if(remove_underscores){
-        return(gsub("_", " ", stripped))
-    }
-    stripped
+##' tr$tip.label %in% genera
+##' }
+##' @export
+strip_ott_ids <- function(tip_labels, remove_underscores = FALSE) {
+  stripped <- sub("_ott\\d+$", "", tip_labels)
+  if (remove_underscores) {
+    return(gsub("_", " ", stripped))
+  }
+  stripped
 }
 
 
@@ -506,7 +527,14 @@ strip_ott_ids <- function(tip_labels, remove_underscores=FALSE){
 ##'
 ##'     \item {node_id} {String. The canonical identifier of the node.}
 ##'
-##'     \item {num_tips} {Numeric. The number of descendent tips.}
+##'     \item {num_tips} {Numeric. The number of descendant tips.}
+##'
+##'     \item {partial_path_of} {List. The edge below this synthetic tree node
+##'     is compatible with the edge below each of these input tree nodes (one
+##'     per tree). Each returned element is reported as sourceid:nodeid.}
+##'
+##'    \item {query} { The node id that resolved to this node. This can differ
+##'    from the node_id field if the query id is not canonical. }
 ##'
 ##'     \item {taxon} {A list of taxonomic properties. Only returned if
 ##'     the queried node is a taxon. Each source has:}
@@ -530,42 +558,20 @@ strip_ott_ids <- function(tip_labels, remove_underscores=FALSE){
 ##'     synthesis source trees. All properties involve sourceid keys and
 ##'     nodeid values (see \code{source_id_map} below).
 ##'
-##'     \item {partial_path_of} {List. The edge below this synthetic tree node
-##'     is compatible with the edge below each of these input tree nodes (one
-##'     per tree). Each returned element is reported as sourceid:nodeid.}
-##'
 ##'     \item {supported_by} {List. Input tree nodes (one per tree) that support
 ##'     this synthetic tree node. Each returned element is reported as
 ##'     sourceid:nodeid.}
 ##'
-##'     \item {terminal} {List. Input tree nodes (one per tree) that are equivalent
-##'     to this synthetic tree node (via an exact mapping, or the input tree
-##'     terminal may be the only terminal descended from this synthetic tree node.
-##'     Each returned element is reported as sourceid:nodeid.}
+##'     \item {terminal} {List. Input tree nodes (one per tree) that are
+##'     equivalent to this synthetic tree node (via an exact mapping, or the
+##'     input tree terminal may be the only terminal descended from this
+##'     synthetic tree node. Each returned element is reported as
+##'     sourceid:nodeid.}
 ##'
 ##'     \item {conflicts_with} {Named list of lists. Names correspond to
-##'     sourceid keys. Each list contains input tree node ids (one or more per tree)
-##'     that conflict with this synthetic node.}
-##'
-##'     \item {source_id_map} {Named list of lists. Names correspond to the
-##'     sourceid keys used in the 4 properties above. Source trees will have the
-##'     following properties:}
-##'
-##'         \itemize{
-##'             \item {git_sha} {The git SHA identifying a particular source
-##'             version.}
-##'
-##'             \item {tree_id} {The tree id associated with the study id used.}
-##'
-##'             \item {study_id} {The study identifier. Will typically include
-##'             a prefix ("pg_" or "ot_").}
-##'         }
-##'     The only sourceid that does not correspond to a source tree is the taxonomy,
-##'     which will have the name "ott"+`taxonomy_version`, and the value is the
-##'     ott_id of the taxon in that taxonomy version. "Taxonomy" will only ever
-##'     appear in \code{supported_by}.
-##'
-##'    }
+##'     sourceid keys. Each list contains input tree node ids (one or more per
+##'     tree) that conflict with this synthetic node.}
+##'   }
 ##'
 ##'     \code{tol_lineage} and \code{tax_lineage} return data
 ##'         frames. \code{tol_lineage} indicate for each ancestor its
@@ -581,35 +587,45 @@ strip_ott_ids <- function(tip_labels, remove_underscores=FALSE){
 ##' tax_lineage(birds)
 ##' tol_lineage(birds)}
 ##' @export
-tol_node_info <- function(ott_id=NULL, node_id=NULL, include_lineage=FALSE, ...) {
-    res <- .tol_node_info(ott_id=ott_id, node_id=node_id,
-                          include_lineage=include_lineage, ...)
-    class(res) <- c("tol_node", class(res))
-    return(res)
+tol_node_info <- function(ott_id = NULL, node_id = NULL, include_lineage = FALSE, ...) {
+  res <- .tol_node_info(
+    ott_id = ott_id, node_id = node_id,
+    include_lineage = include_lineage, ...
+  )
+  class(res) <- c("tol_node", class(res))
+  return(res)
 }
 
 tol_node_method_factory <- function(.f) {
-    function(tax, ...) {
-        res <- setNames(list(.f(tax[["taxon"]])),
-                        .tax_unique_name(tax[["taxon"]]))
-        res <- add_otl_class(res, .f)
-        res
+  function(tax, ...) {
+    if (exists("taxon", tax)) {
+      res <- setNames(
+        list(.f(tax[["taxon"]])),
+        .tax_unique_name(tax[["taxon"]])
+      )
+    } else if (exists("node_id", tax)) {
+      res <- setNames(tax[["node_id"]], tax[["node_id"]])
+    } else {
+      res <- NA
     }
+    res <- add_otl_class(res, .f)
+    res
+  }
 }
 
 ##' @export
 print.tol_node <- function(x, ...) {
-    cat("\nOpenTree node.\n\n")
-    cat("Node id: ", x$node_id, "\n", sep="")
-    cat("Number of terminal descendants: ", x$num_tips, "\n", sep="")
-    if (is_taxon(x[["taxon"]])) {
-        cat("Is taxon: TRUE\n")
-        cat("Name: ", x$taxon$name, "\n", sep="")
-        cat("Rank: ", x$taxon$rank, "\n", sep="")
-        cat("ott id: ", x$taxon$ott_id, "\n", sep="")
-    } else {
-        cat("Is taxon: FALSE\n")
-    }
+  cat("\nOpenTree node.\n\n")
+  cat("Node id: ", x$node_id, "\n", sep = "")
+  cat("Number of terminal descendants: ", x$num_tips, "\n", sep = "")
+  if (is_taxon(x[["taxon"]])) {
+    cat("Is taxon: TRUE\n")
+    cat("Name: ", x$taxon$name, "\n", sep = "")
+    cat("Rank: ", x$taxon$rank, "\n", sep = "")
+    cat("ott id: ", x$taxon$ott_id, "\n", sep = "")
+  } else {
+    cat("Is taxon: FALSE\n")
+  }
 }
 
 ##' @export
@@ -640,29 +656,30 @@ source_list.tol_node <- .source_list
 ##' @export
 ##' @rdname tol_node_info
 tax_lineage.tol_node <- function(tax, ...) {
-    check_lineage(tax)
-    lg <- lapply(tax[["lineage"]], function(x) {
-        if (exists("taxon", x)) {
-            build_lineage(x[["taxon"]])
-        } else {
-            NULL
-        }
-
-    })
-    lg <- do.call("rbind", lg)
-    as.data.frame(lg, stringsAsFactors = FALSE)
+  check_lineage(tax)
+  lg <- lapply(tax[["lineage"]], function(x) {
+    if (exists("taxon", x)) {
+      build_lineage(x[["taxon"]])
+    } else {
+      NULL
+    }
+  })
+  lg <- do.call("rbind", lg)
+  as.data.frame(lg, stringsAsFactors = FALSE)
 }
 
 
 ##' @export
 ##' @rdname tol_node_info
 tol_lineage.tol_node <- function(tax, ...) {
-    check_lineage(tax)
-    lg <- lapply(tax[["lineage"]], function(x) {
-        c("node_id" = x[["node_id"]],
-          "num_tips" = x[["num_tips"]],
-          "is_taxon" = exists("taxon", x))
-    })
-    lg <- do.call("rbind", lg)
-    as.data.frame(lg, stringsAsFactors = FALSE)
+  check_lineage(tax)
+  lg <- lapply(tax[["lineage"]], function(x) {
+    c(
+      "node_id" = x[["node_id"]],
+      "num_tips" = x[["num_tips"]],
+      "is_taxon" = exists("taxon", x)
+    )
+  })
+  lg <- do.call("rbind", lg)
+  as.data.frame(lg, stringsAsFactors = FALSE)
 }
